// 
// Patron pour la generation d'une classe derivee dans ROOT
// FNetDataServer derive de TObject
// 
 
#ifndef FNetDataServer_h 
#define FNetDataServer_h 
 
#include "TObject.h" 
#include "TMonitor.h" 
#include "TList.h" 
#include "TServerSocket.h" 
#include "FNetConnection.h" 
#include "TMessage.h" 
 
class FNetDataServer : public FNetConnection { 
 
   protected:
	static Int_t Debug;

   	TServerSocket *sso;
   	TMonitor *monitor;
   	Int_t nosock;
   	Int_t reads;
   	Int_t provs;
   	TList *loprovsock;
   	TList *loreadsock;
   	TList *loobj;
	
	Long_t lsent;
	Long_t lrecv;

   protected: 
        virtual void Init(void);       // initialisation 
 
   public:	 
        static void SetDebug(Int_t d=0) {FNetDataServer::Debug=d;}
        static Int_t GetDebug(void) {return FNetDataServer::Debug;}
	
   	FNetDataServer(void);    // constructeur par defaut 
	FNetDataServer(const FNetDataServer &ap); // constructeur par copie 
	
	~FNetDataServer(void);		// desctructeur; 
	 
#if ROOT_VERSION_CODE >= ROOT_VERSION(3,4,0)
   	virtual void Copy(TObject & obj) const;
#else
   	virtual void Copy(TObject & obj);
#endif
	FNetDataServer& operator = (const FNetDataServer &hp); // operateur = 

	virtual void LaunchDataServer(Int_t port=9090);
	virtual void AddSocket(void);
	virtual void RemoveSocket(void);
	virtual TSocket *GetCurrentSocket(void) const {return sock;}
	virtual void SetCurrentSocket(TSocket *s){sock=s;}
	virtual void MainLoop(void);
	virtual void TerminateDataServer(void);
	virtual void AddObject(TObject *o);
	virtual void AddList(TList *o);
	virtual void ProcessMessage(TMessage *m);
	virtual Bool_t IsCurrentReader(void);
	virtual Bool_t IsCurrentProvider(void);
	virtual void PrintSockectInfos(void);
	virtual Bool_t CheckSocketStatus(void);
 
    ClassDef(FNetDataServer,1)
 
}; 
 
#endif 
 
