// 
// Patron pour la generation d'une classe derivee dans ROOT
// MFHScaleManager derive de TGCompositeFrame
// 
 
#ifndef MFHScaleManager_h 
#define MFHScaleManager_h 
 
#include "TROOT.h"
#include "TGClient.h"
#include "FEventProcessorThread.h" 
#include "MCBLabel.h" 
#include "MTELabel.h" 
#include "FHScale.h" 
 
class MFHScaleManager : public TGCompositeFrame { 

	enum ElementId 
	{
	CB_scaleName,
	LB_paramsBox,
	B_addToScale,
	B_removeFromScale,
	LB_scaleParamsBox
	};
 
   private: 
	FEventProcessorThread 	*fept;
	MCBLabel		*scaleName;
	TGListBox		*paramsBox;
	TGListBox		*scaleParamsBox;
	TGTextButton		*addToScale;
	TGTextButton		*removeFromScale;
	TGTextButton		*resetScaleParams;
	TGTextButton		*addAllParamsToScale;
	Int_t			firstPBentry,lastPBentry;
	Int_t			firstPSBentry,lastPSBentry;
	TH1	 		*currentScale;

   protected: 
        virtual void Init(void);       // initialisation 
 
   public:	 
	MFHScaleManager(const TGWindow *p=0,UInt_t w=500,UInt_t h=300);
#if ROOT_VERSION_CODE <= ROOT_VERSION(5,12,0)
	MFHScaleManager(const MFHScaleManager &ap); // constructeur par copie 
#endif	
	~MFHScaleManager(void);		// desctructeur; 
	 
#if ROOT_VERSION_CODE >= ROOT_VERSION(3,4,0)
   	virtual void Copy(TObject & obj) const;
#else
   	virtual void Copy(TObject & obj);
#endif
	MFHScaleManager& operator = (const MFHScaleManager &hp); // operateur = 
 
	virtual Bool_t ProcessMessage(Long_t msg, Long_t par1, Long_t par2); 

	virtual FEventProcessorThread *GetFEventProcessorThread(void)
		{return fept;}
	virtual void SetFEventProcessorThread(FEventProcessorThread *f=0)
		{fept=f;}

	virtual void Reset(void);
	virtual void SetParamList(void);
	virtual void AddParam(Char_t *s);
	virtual void RemoveParam(Char_t *s);
	virtual Int_t GetParamBoxId(Char_t *s);
	virtual void ResetParams(void);
	virtual void AddScale(Char_t *s);
	virtual void RemoveScale(Char_t *s);
	virtual void SetScaleList(void);
	virtual void SetScaleParamList(void);
	virtual void AddScaleParam(Char_t *s);
	virtual void RemoveScaleParam(Char_t *s);
	virtual Int_t GetScaleParamBoxId(Char_t *s);
	virtual void ResetScaleParams(void);
	virtual void AddParamsToScale(void);
	virtual void RemoveParamsFromScale(void);
	virtual void AddAllParamsToScale(void);
	virtual void RemoveAllParamsFromScale(void);
	
	virtual void WarningBox(char const *title="Warning",char const *msg="Warning");

    ClassDef(MFHScaleManager,1)
 
}; 
 
#endif 
 
